#!/bin/sh

# THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
# 5724-I04 (C) COPYRIGHT International Business Machines Corp., 1997,2007
# All Rights Reserved * Licensed Materials - Property of IBM
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

IFIX=LI73605
IFIX_LOG=$WVS_ROOT/log/$IFIX.log

# ifix launcher
thisHostname=`hostname -s`
thisDir=`dirname "$0"`
errorsduringinstall=0

if [ ! "$2" ] 
then
  if [  -f ./$IFIX.sh ]
 then
 echo "Ifix_$IFIX: WVS Ifix $IFIX Installer command syntax: "
 echo "  "
 echo " to install ifix  syntax: ifix_$IFIX.sh  -install "
 echo "  "
 echo " to uninstall ifix  syntax: ifix_$IFIX.sh -uninstall "
 echo " "
 exit -1
 fi
fi

if [ $# -eq 0 ]
then
 echo "Ifix_$IFIX: WVS Ifix $IFIX Installer command syntax: "
 echo " to install ifix  syntax: ifix_$IFIX -install "
 echo "  "
 echo " to uninstall ifix  syntax: ifix_$IFIX.sh -uninstall "
 echo " "
 exit -1
fi

if [ -f /opt/WebSphere/AppServer/bin/setupCmdLine.sh ]
then
   . /opt/WebSphere/AppServer/bin/setupCmdLine.sh
fi
   
   
if [ ! "$WAS_HOME" ] ; then
   echo "Ifix_$IFIX: Please run WebSphere Application Server's setupCmdLine.sh to setup"
   echo "         the WAS Command line environment"
  exit -1
fi

if [ ! "$WVS_ROOT" ] ; then
   echo "Ifix_$IFIX: Please configure WebSphere Voice Server wvs.setenv according"
   echo "         to the WVS InfoCenter "
  exit -1
fi


isInstallOption=false
isUnInstallOption=false
nonJavaOptionCount=1
for option in "$@" ; do
  if [ "$option" = "-install" ] ; then
     isInstallOption=true
  else
     if [ "$option" = "-uninstall" ] ; then
        isUnInstallOption=true
     fi
  fi
done

if [ "$isInstallOption" = "true" ] ; then
  if [ -f $WVS_ROOT/ifix/$IFIX/voiceTest.jar.bak ] ; then
    echo "Ifix_$IFIX: Ifix $IFIX is applied, please uninstall before trying to reinstall ifix"
    exit -1
  fi
  if [ ! -d $WVS_ROOT/fixes/5.1.3.3 ] ; then
    echo "Ifix_IY85112: Pre-requisite Fixpack 5.1.3.3 is not applied, please install Fixpack 5.1.3.3 before trying to install ifix $IFIX"
    exit -1
  fi
fi

if [ "$isInstallOption" = "true" ] ; then
 # Check that the ifix files are found
 echo "Ifix_$IFIX: Checking for ifix files ..."
  if [ -f $thisDir/voiceTest.jar ] ; then
	echo "Ifix_$IFIX: Ifix files found.. proceeding to install ifix" >> $IFIX_LOG
	echo "Ifix_$IFIX: Ifix files found.. proceeding to install ifix"
	mkdir -p $WVS_ROOT/ifix/$IFIX >> $IFIX_LOG
	cp -p $thisDir/$IFIX.sh $WVS_ROOT/ifix/ifix_$IFIX.sh >> $IFIX_LOG
	cp -p $WVS_ROOT/lib/voiceTest.jar $WVS_ROOT/ifix/$IFIX/voiceTest.jar.bak >> $IFIX_LOG
	cp -fp $thisDir/voiceTest.jar $WVS_ROOT/lib/. >> $IFIX_LOG

	echo "Ifix_$IFIX: Ifix is now applied" >> $IFIX_LOG
	echo "Ifix_$IFIX: Ifix is now applied"
  else
    echo "Ifix_$IFIX: Ifix files missing, please be sure this script is in same directory as the binary files" >> $IFIX_LOG
    echo "Ifix_$IFIX: Ifix files missing, please be sure this script is in same directory as the binary files" 
  fi
  cp -fp $thisDir/$IFIX.log $WVS_ROOT/log/. >> $IFIX_LOG
fi

if [ "$isUnInstallOption" = "true" ] ; then
 # Check that the ifix backup files are found
 echo "Ifix_$IFIX: Checking for ifix backup files ..." >> $IFIX_LOG
 echo "Ifix_$IFIX: Checking for ifix backup files ..."
  if [ -f $WVS_ROOT/ifix/$IFIX/voiceTest.jar.bak ] ; then
      echo "Ifix_$IFIX: Ifix backup files found.. proceeding to un-install ifix" >> $IFIX_LOG
      echo "Ifix_$IFIX: Ifix backup files found.. proceeding to un-install ifix"
      
      cp -fp $WVS_ROOT/ifix/$IFIX/voiceTest.jar.bak $WVS_ROOT/lib/voiceTest.jar >> $IFIX_LOG	  

      echo "Ifix_$IFIX: Ifix is now uninstalled. Please, remove the $WVS_ROOT/ifix/$IFIX" >> $IFIX_LOG
      echo "Ifix_$IFIX:   directory before attempting a subsequent install of this ifix." >> $IFIX_LOG
      
      echo "Ifix_$IFIX: Ifix is now uninstalled. Please, remove the $WVS_ROOT/ifix/$IFIX" 
      echo "Ifix_$IFIX:   directory before attempting a subsequent install of this ifix."
  else
    echo "Ifix_$IFIX: Ifix backup files missing, uninstall not performed" >> $IFIX_LOG
    echo "Ifix_$IFIX: Ifix backup files missing, uninstall not performed"
  fi
fi
exit $?
